==> Bundle-Theory-1.04.tar.gz: Bundle-Theory-1.04/lib/Bundle/Theory.pm <==
package Bundle::Theory;

# $Id: Theory.pm 3632 2008-04-09 22:15:25Z david $

our $VERSION = '1.04';

1;
__END__

=begin comment

Fake-out Module::Build. Delete if it ever changes to support =head1 headers
other than all uppercase.

=head1 NAME

Bundle::Theory - A bundle to install all of Theory's favorite modules

=end comment

=head1 Name

Bundle::Theory - A bundle to install all of Theory's favorite modules

=head1 Synopsis

  perl -MCPAN -e 'install Bundle::Theory'

=head1 Description

This bundle contains all of Theory's most-used CPAN modules. These are
essentials whenever I he builds a new system.

=head1 CONTENTS

Term::ReadLine::Perl

Cwd

Bundle::CPAN

Bundle::libnet

Bundle::LWP

Module::Build

Module::Install

ExtUtils::MakeMaker

CPANPLUS

CPAN::Reporter

Test::Reporter

CPAN::SQLite

Parse::RecDescent

YAML

DBI

DBD::SQLite

DBD::Pg

App::Info

Class::Delegator

Data::Types

Class::Meta

Class::Meta::Express

Encode::ZapCP1252

Exception::Class::DBI

FSA::Rules

Lingua::Strfname

Params::CallbackRequest

MasonX::Interp::WithCallbacks

Module::Build::JSAN

SVN::Notify

SVN::Notify::Filter::Markdown

Text::Diff::HTML

Text::WordDiff

Time::Piece::ISO

Widget::Meta

Text::Password::Pronounceable

XMLRPC::Lite

Time::HiRes

Cache::Cache

Cache::Mmap

CHI

Cache::Memcached

Digest::MD5

Digest::SHA1

URI

HTML::Parser

HTML::HeadParser

MIME::Base64

MIME::Tools

MIME::Types

MIME::Lite

Bundle::Email

Email::Valid

Module::Starter

Image::Info

Params::Validate

DB_File

XML::Parser

XML::Simple

XML::Generator

XML::LibXML

XML::Writer

XML::SAX

IO::Stringy

File::Path

File::Temp

Text::LevenshteinXS

Locale::Maketext

DateTime

DateTime::TimeZone

DateTime::Incomplete

DateTime::Format::Strptime

Encode

Event

Term::ReadPassword

List::Util

List::MoreUtils

URI::Escape

Iterator

Iterator::Util

aliased

Array::AsHash

Class::BuildMethods

Class::Trait

Data::Dumper::Names

Data::Dumper

PPI

Perl::Critic

HOP::Stream

HOP::Lexer

HOP::Parser

TAP::Parser

Parse::RecDescent

Pod::Simple

TAP::Harness

Test::Harness

Test::More

Test::MockModule

Test::Class

Test::Pod

Test::Pod::Coverage

Test::JSON

Test::XML

Test::Output

Test::Deep

Test::Differences

Test::Differences

Test::Exception

Test::File

Test::File::Contents

Test::NoWarnings

Test::Data::Array

Test::Number::Delta

Test::Trap

Test::Perl::Critic

Exporter::Tidy

File::Find::Rule

JSON::XS

JSON

JSON::Syck

Lingua::EN::Inflect

Regexp::Common

App::Cmd

version

Net::SSLeay

Net::LDAP

CGI

HTML::Mason

HTML::Template

Template

Imager

Image::Info

IO::All

Net::Daemon

Net::FTPServer

Text::Iconv

CPAN::Mini

Data::GUID

Class::MOP

Return::Value

Sub::Exporter

Moose

Want

App::Ack

Modul::CoreList

Perl::Tidy

Scalar::Util

Text::Markdown

Text::MultiMarkdown

Text::Trac

=head1 Author

=begin comment

Fake-out Module::Build. Delete if it ever changes to support =head1 headers
other than all uppercase.

=head1 AUTHOR

=end comment

David E. Wheeler <david@kineticode.com>

=head1 License

This module is free software; you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut

==> Bundle-Theory-1.05.tar.gz: Bundle-Theory-1.05/lib/Bundle/Theory.pm <==
package Bundle::Theory;

# $Id: Theory.pm 3637 2008-04-10 02:25:22Z david $

our $VERSION = '1.05';

1;
__END__

=begin comment

Fake-out Module::Build. Delete if it ever changes to support =head1 headers
other than all uppercase.

=head1 NAME

Bundle::Theory - A bundle to install all of Theory's favorite modules

=end comment

=head1 Name

Bundle::Theory - A bundle to install all of Theory's favorite modules

=head1 Synopsis

  perl -MCPAN -e 'install Bundle::Theory'

=head1 Description

This bundle contains all of Theory's most-used CPAN modules. These are
essentials whenever he builds a new system.

=head1 CONTENTS

Term::ReadLine::Perl

Cwd

Bundle::CPAN

Bundle::libnet

Bundle::LWP

Module::Build

Module::Install

ExtUtils::MakeMaker

CPANPLUS

CPAN::Reporter

Test::Reporter

CPAN::SQLite

Parse::RecDescent

YAML

DBI

DBD::SQLite

DBD::Pg

App::Info

Class::Delegator

Data::Types

Class::Meta

Class::Meta::Express

Encode::ZapCP1252

Exception::Class::DBI

FSA::Rules

Lingua::Strfname

Params::CallbackRequest

MasonX::Interp::WithCallbacks

Module::Build::JSAN

SVN::Notify

SVN::Notify::Filter::Markdown

Text::Diff::HTML

Text::WordDiff

Time::Piece::ISO

Widget::Meta

Text::Password::Pronounceable

XMLRPC::Lite

Time::HiRes

Cache::Cache

Cache::Mmap

CHI

Cache::Memcached

Digest::MD5

Digest::SHA1

URI

HTML::Parser

HTML::HeadParser

MIME::Base64

MIME::Tools

MIME::Types

MIME::Lite

Bundle::Email

Email::Valid

Module::Starter

Image::Info

Params::Validate

DB_File

XML::Parser

XML::Simple

XML::Generator

XML::LibXML

XML::Writer

XML::SAX

IO::Stringy

File::Path

File::Temp

Text::LevenshteinXS

Locale::Maketext

DateTime

DateTime::TimeZone

DateTime::Incomplete

DateTime::Format::Strptime

Encode

Event

Term::ReadPassword

List::Util

List::MoreUtils

URI::Escape

Iterator

Iterator::Util

aliased

Array::AsHash

Class::BuildMethods

Class::Trait

Data::Dumper::Names

Data::Dumper

PPI

Perl::Critic

HOP::Stream

HOP::Lexer

HOP::Parser

TAP::Parser

Parse::RecDescent

Pod::Simple

TAP::Harness

Test::Harness

Test::More

Test::MockModule

Test::Class

Test::Pod

Test::Pod::Coverage

Test::JSON

Test::XML

Test::Output

Test::Deep

Test::Differences

Test::Differences

Test::Exception

Test::File

Test::File::Contents

Test::NoWarnings

Test::Data::Array

Test::Number::Delta

Test::Trap

Test::Perl::Critic

Exporter::Tidy

File::Find::Rule

JSON::XS

JSON

JSON::Syck

Lingua::EN::Inflect

Regexp::Common

App::Cmd

version

Net::SSLeay

Net::LDAP

CGI

HTML::Mason

HTML::Template

HTML::Template::Expr

Template

Imager

Image::Info

IO::All

Net::Daemon

Net::FTPServer

Text::Iconv

CPAN::Mini

Data::GUID

Class::MOP

Return::Value

Sub::Exporter

Moose

Want

App::Ack

Modul::CoreList

Perl::Tidy

Scalar::Util

Text::Markdown

Text::MultiMarkdown

Text::Trac

=head1 Author

=begin comment

Fake-out Module::Build. Delete if it ever changes to support =head1 headers
other than all uppercase.

=head1 AUTHOR

=end comment

David E. Wheeler <david@kineticode.com>

=head1 License

This module is free software; you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut
